# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    AsanaAuthenticationTypes,
    AttioAuthenticationTypes,
    AttioFeedAuthenticationTypes,
    AttioIssueAuthenticationTypes,
    AttioMeetingAuthenticationTypes,
    BambooHRAuthenticationTypes,
    BlobListingTypes,
    BoxAuthenticationTypes,
    CalendarListingTypes,
    ConfluenceAuthenticationTypes,
    ConfluenceTypes,
    CrustdataWatcherSignalTypes,
    DropboxAuthenticationTypes,
    EmailListingTypes,
    EntityState,
    ExaSearchTypes,
    FeedListingTypes,
    FeedServiceTypes,
    FeedSyncMode,
    FeedTypes,
    GitHubAuthenticationTypes,
    GitHubCommitAuthenticationTypes,
    GitHubPullRequestAuthenticationTypes,
    GoogleCalendarAuthenticationTypes,
    GoogleContactsAuthenticationTypes,
    GoogleDriveAuthenticationTypes,
    GoogleEmailAuthenticationTypes,
    GustoAuthenticationTypes,
    HubSpotAuthenticationTypes,
    HubSpotFeedAuthenticationTypes,
    HubSpotIssueAuthenticationTypes,
    IntercomAuthenticationTypes,
    IntercomConversationsAuthenticationTypes,
    IntercomIssueAuthenticationTypes,
    JiraAuthenticationTypes,
    LinearAuthenticationTypes,
    LinkedInPostContentTypes,
    LinkedInPostListingTypes,
    MeetingContentTypes,
    MicrosoftCalendarAuthenticationTypes,
    MicrosoftContactsAuthenticationTypes,
    MicrosoftEmailAuthenticationTypes,
    MicrosoftTeamsAuthenticationTypes,
    NotionAuthenticationTypes,
    NotionTypes,
    OneDriveAuthenticationTypes,
    ParallelGenerators,
    ParallelProcessors,
    SalesforceAuthenticationTypes,
    SalesforceFeedAuthenticationTypes,
    SalesforceIssueAuthenticationTypes,
    SearchServiceTypes,
    SharePointAuthenticationTypes,
    SiteTypes,
    SlackAuthenticationTypes,
    TimedPolicyRecurrenceTypes,
    TrelloTypes,
    TwitterAuthenticationTypes,
    TwitterListingTypes,
    YouTubeTypes,
    ZendeskAuthenticationTypes,
    ZendeskIssueAuthenticationTypes,
)


class QueryFeeds(BaseModel):
    feeds: Optional["QueryFeedsFeeds"]


class QueryFeedsFeeds(BaseModel):
    results: Optional[list["QueryFeedsFeedsResults"]]


class QueryFeedsFeedsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryFeedsFeedsResultsOwner"
    state: EntityState
    identifier: Optional[str]
    description: Optional[str]
    correlation_id: Optional[str] = Field(alias="correlationId")
    type: FeedTypes
    sync_mode: Optional[FeedSyncMode] = Field(alias="syncMode")
    site: Optional["QueryFeedsFeedsResultsSite"]
    email: Optional["QueryFeedsFeedsResultsEmail"]
    issue: Optional["QueryFeedsFeedsResultsIssue"]
    initiative: Optional["QueryFeedsFeedsResultsInitiative"]
    commit: Optional["QueryFeedsFeedsResultsCommit"]
    pull_request: Optional["QueryFeedsFeedsResultsPullRequest"] = Field(
        alias="pullRequest"
    )
    crm: Optional["QueryFeedsFeedsResultsCrm"]
    hris: Optional["QueryFeedsFeedsResultsHris"]
    calendar: Optional["QueryFeedsFeedsResultsCalendar"]
    meeting: Optional["QueryFeedsFeedsResultsMeeting"]
    rss: Optional["QueryFeedsFeedsResultsRss"]
    web: Optional["QueryFeedsFeedsResultsWeb"]
    search: Optional["QueryFeedsFeedsResultsSearch"]
    reddit: Optional["QueryFeedsFeedsResultsReddit"]
    linked_in: Optional["QueryFeedsFeedsResultsLinkedIn"] = Field(alias="linkedIn")
    notion: Optional["QueryFeedsFeedsResultsNotion"]
    confluence: Optional["QueryFeedsFeedsResultsConfluence"]
    intercom: Optional["QueryFeedsFeedsResultsIntercom"]
    zendesk: Optional["QueryFeedsFeedsResultsZendesk"]
    youtube: Optional["QueryFeedsFeedsResultsYoutube"]
    twitter: Optional["QueryFeedsFeedsResultsTwitter"]
    slack: Optional["QueryFeedsFeedsResultsSlack"]
    microsoft_teams: Optional["QueryFeedsFeedsResultsMicrosoftTeams"] = Field(
        alias="microsoftTeams"
    )
    discord: Optional["QueryFeedsFeedsResultsDiscord"]
    attio: Optional["QueryFeedsFeedsResultsAttio"]
    salesforce: Optional["QueryFeedsFeedsResultsSalesforce"]
    hub_spot_conversations: Optional["QueryFeedsFeedsResultsHubSpotConversations"] = (
        Field(alias="hubSpotConversations")
    )
    intercom_conversations: Optional["QueryFeedsFeedsResultsIntercomConversations"] = (
        Field(alias="intercomConversations")
    )
    productlane: Optional["QueryFeedsFeedsResultsProductlane"]
    research: Optional["QueryFeedsFeedsResultsResearch"]
    entity: Optional["QueryFeedsFeedsResultsEntity"]
    error: Optional[str]
    last_post_date: Optional[Any] = Field(alias="lastPostDate")
    last_read_date: Optional[Any] = Field(alias="lastReadDate")
    read_count: Optional[int] = Field(alias="readCount")
    workflow: Optional["QueryFeedsFeedsResultsWorkflow"]
    schedule_policy: Optional["QueryFeedsFeedsResultsSchedulePolicy"] = Field(
        alias="schedulePolicy"
    )


class QueryFeedsFeedsResultsOwner(BaseModel):
    id: str


class QueryFeedsFeedsResultsSite(BaseModel):
    site_type: SiteTypes = Field(alias="siteType")
    type: FeedServiceTypes
    is_recursive: Optional[bool] = Field(alias="isRecursive")
    allowed_paths: Optional[list[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[list[str]] = Field(alias="excludedPaths")
    s_3: Optional["QueryFeedsFeedsResultsSiteS3"] = Field(alias="s3")
    azure_blob: Optional["QueryFeedsFeedsResultsSiteAzureBlob"] = Field(
        alias="azureBlob"
    )
    azure_file: Optional["QueryFeedsFeedsResultsSiteAzureFile"] = Field(
        alias="azureFile"
    )
    google: Optional["QueryFeedsFeedsResultsSiteGoogle"]
    share_point: Optional["QueryFeedsFeedsResultsSiteSharePoint"] = Field(
        alias="sharePoint"
    )
    one_drive: Optional["QueryFeedsFeedsResultsSiteOneDrive"] = Field(alias="oneDrive")
    google_drive: Optional["QueryFeedsFeedsResultsSiteGoogleDrive"] = Field(
        alias="googleDrive"
    )
    dropbox: Optional["QueryFeedsFeedsResultsSiteDropbox"]
    box: Optional["QueryFeedsFeedsResultsSiteBox"]
    github: Optional["QueryFeedsFeedsResultsSiteGithub"]
    read_limit: Optional[int] = Field(alias="readLimit")


class QueryFeedsFeedsResultsSiteS3(BaseModel):
    access_key: Optional[str] = Field(alias="accessKey")
    secret_access_key: Optional[str] = Field(alias="secretAccessKey")
    bucket_name: Optional[str] = Field(alias="bucketName")
    prefix: Optional[str]
    region: Optional[str]
    custom_endpoint: Optional[str] = Field(alias="customEndpoint")


class QueryFeedsFeedsResultsSiteAzureBlob(BaseModel):
    storage_access_key: Optional[str] = Field(alias="storageAccessKey")
    account_name: Optional[str] = Field(alias="accountName")
    container_name: Optional[str] = Field(alias="containerName")
    prefix: Optional[str]
    list_type: Optional[BlobListingTypes] = Field(alias="listType")


class QueryFeedsFeedsResultsSiteAzureFile(BaseModel):
    storage_access_key: Optional[str] = Field(alias="storageAccessKey")
    account_name: Optional[str] = Field(alias="accountName")
    share_name: Optional[str] = Field(alias="shareName")
    prefix: Optional[str]


class QueryFeedsFeedsResultsSiteGoogle(BaseModel):
    credentials: Optional[str]
    container_name: Optional[str] = Field(alias="containerName")
    prefix: Optional[str]


class QueryFeedsFeedsResultsSiteSharePoint(BaseModel):
    authentication_type: Optional[SharePointAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    account_name: str = Field(alias="accountName")
    library_id: str = Field(alias="libraryId")
    folder_id: Optional[str] = Field(alias="folderId")
    tenant_id: Optional[str] = Field(alias="tenantId")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsSiteSharePointConnector"]


class QueryFeedsFeedsResultsSiteSharePointConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsSiteOneDrive(BaseModel):
    authentication_type: Optional[OneDriveAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    folder_id: Optional[str] = Field(alias="folderId")
    files: Optional[list[Optional[str]]]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsSiteOneDriveConnector"]


class QueryFeedsFeedsResultsSiteOneDriveConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsSiteGoogleDrive(BaseModel):
    authentication_type: Optional[GoogleDriveAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    drive_id: Optional[str] = Field(alias="driveId")
    folder_id: Optional[str] = Field(alias="folderId")
    files: Optional[list[Optional[str]]]
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    service_account_json: Optional[str] = Field(alias="serviceAccountJson")
    connector: Optional["QueryFeedsFeedsResultsSiteGoogleDriveConnector"]


class QueryFeedsFeedsResultsSiteGoogleDriveConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsSiteDropbox(BaseModel):
    authentication_type: Optional[DropboxAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    path: Optional[str]
    app_key: Optional[str] = Field(alias="appKey")
    app_secret: Optional[str] = Field(alias="appSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsSiteDropboxConnector"]


class QueryFeedsFeedsResultsSiteDropboxConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsSiteBox(BaseModel):
    authentication_type: Optional[BoxAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    folder_id: Optional[str] = Field(alias="folderId")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    redirect_uri: Optional[str] = Field(alias="redirectUri")
    connector: Optional["QueryFeedsFeedsResultsSiteBoxConnector"]


class QueryFeedsFeedsResultsSiteBoxConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsSiteGithub(BaseModel):
    authentication_type: Optional[GitHubAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    connector: Optional["QueryFeedsFeedsResultsSiteGithubConnector"]


class QueryFeedsFeedsResultsSiteGithubConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsEmail(BaseModel):
    type: FeedServiceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    google: Optional["QueryFeedsFeedsResultsEmailGoogle"]
    microsoft: Optional["QueryFeedsFeedsResultsEmailMicrosoft"]
    read_limit: Optional[int] = Field(alias="readLimit")


class QueryFeedsFeedsResultsEmailGoogle(BaseModel):
    type: Optional[EmailListingTypes]
    filter: Optional[str]
    include_spam: Optional[bool] = Field(alias="includeSpam")
    exclude_sent_items: Optional[bool] = Field(alias="excludeSentItems")
    include_deleted_items: Optional[bool] = Field(alias="includeDeletedItems")
    inbox_only: Optional[bool] = Field(alias="inboxOnly")
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    authentication_type: Optional[GoogleEmailAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    connector: Optional["QueryFeedsFeedsResultsEmailGoogleConnector"]


class QueryFeedsFeedsResultsEmailGoogleConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsEmailMicrosoft(BaseModel):
    type: Optional[EmailListingTypes]
    filter: Optional[str]
    include_spam: Optional[bool] = Field(alias="includeSpam")
    exclude_sent_items: Optional[bool] = Field(alias="excludeSentItems")
    include_deleted_items: Optional[bool] = Field(alias="includeDeletedItems")
    inbox_only: Optional[bool] = Field(alias="inboxOnly")
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    authentication_type: Optional[MicrosoftEmailAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    connector: Optional["QueryFeedsFeedsResultsEmailMicrosoftConnector"]


class QueryFeedsFeedsResultsEmailMicrosoftConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsIssue(BaseModel):
    type: FeedServiceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    jira: Optional["QueryFeedsFeedsResultsIssueJira"]
    linear: Optional["QueryFeedsFeedsResultsIssueLinear"]
    github: Optional["QueryFeedsFeedsResultsIssueGithub"]
    intercom: Optional["QueryFeedsFeedsResultsIssueIntercom"]
    zendesk: Optional["QueryFeedsFeedsResultsIssueZendesk"]
    trello: Optional["QueryFeedsFeedsResultsIssueTrello"]
    attio: Optional["QueryFeedsFeedsResultsIssueAttio"]
    salesforce: Optional["QueryFeedsFeedsResultsIssueSalesforce"]
    hub_spot: Optional["QueryFeedsFeedsResultsIssueHubSpot"] = Field(alias="hubSpot")
    asana: Optional["QueryFeedsFeedsResultsIssueAsana"]
    monday: Optional["QueryFeedsFeedsResultsIssueMonday"]
    productlane: Optional["QueryFeedsFeedsResultsIssueProductlane"]
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    read_limit: Optional[int] = Field(alias="readLimit")


class QueryFeedsFeedsResultsIssueJira(BaseModel):
    authentication_type: Optional[JiraAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    project: Optional[str]
    email: Optional[str]
    token: Optional[str]
    offset: Optional[Any]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsIssueJiraConnector"]
    cloud_id: Optional[str] = Field(alias="cloudId")


class QueryFeedsFeedsResultsIssueJiraConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsIssueLinear(BaseModel):
    authentication_type: Optional[LinearAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    key: Optional[str]
    project: str
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsIssueLinearConnector"]


class QueryFeedsFeedsResultsIssueLinearConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsIssueGithub(BaseModel):
    authentication_type: Optional[GitHubAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    connector: Optional["QueryFeedsFeedsResultsIssueGithubConnector"]


class QueryFeedsFeedsResultsIssueGithubConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsIssueIntercom(BaseModel):
    authentication_type: Optional[IntercomIssueAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    access_token: Optional[str] = Field(alias="accessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsIssueIntercomConnector"]


class QueryFeedsFeedsResultsIssueIntercomConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsIssueZendesk(BaseModel):
    authentication_type: Optional[ZendeskIssueAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    subdomain: str
    access_token: Optional[str] = Field(alias="accessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsIssueZendeskConnector"]


class QueryFeedsFeedsResultsIssueZendeskConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsIssueTrello(BaseModel):
    key: str
    token: str
    identifiers: list[str]
    type: TrelloTypes


class QueryFeedsFeedsResultsIssueAttio(BaseModel):
    authentication_type: Optional[AttioIssueAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    api_key: Optional[str] = Field(alias="apiKey")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsIssueAttioConnector"]


class QueryFeedsFeedsResultsIssueAttioConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsIssueSalesforce(BaseModel):
    authentication_type: Optional[SalesforceIssueAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    is_sandbox: Optional[bool] = Field(alias="isSandbox")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsIssueSalesforceConnector"]


class QueryFeedsFeedsResultsIssueSalesforceConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsIssueHubSpot(BaseModel):
    authentication_type: Optional[HubSpotIssueAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    access_token: Optional[str] = Field(alias="accessToken")
    connector: Optional["QueryFeedsFeedsResultsIssueHubSpotConnector"]


class QueryFeedsFeedsResultsIssueHubSpotConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsIssueAsana(BaseModel):
    authentication_type: Optional[AsanaAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    workspace_id: Optional[str] = Field(alias="workspaceId")
    project_id: Optional[str] = Field(alias="projectId")


class QueryFeedsFeedsResultsIssueMonday(BaseModel):
    api_token: str = Field(alias="apiToken")
    board_id: str = Field(alias="boardId")


class QueryFeedsFeedsResultsIssueProductlane(BaseModel):
    api_key: Optional[str] = Field(alias="apiKey")
    workspace_id: Optional[str] = Field(alias="workspaceId")


class QueryFeedsFeedsResultsInitiative(BaseModel):
    type: FeedServiceTypes
    jira: Optional["QueryFeedsFeedsResultsInitiativeJira"]
    github: Optional["QueryFeedsFeedsResultsInitiativeGithub"]
    linear: Optional["QueryFeedsFeedsResultsInitiativeLinear"]
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    read_limit: Optional[int] = Field(alias="readLimit")


class QueryFeedsFeedsResultsInitiativeJira(BaseModel):
    authentication_type: Optional[JiraAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[str]
    project: Optional[str]
    email: Optional[str]
    token: Optional[str]
    offset: Optional[Any]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsInitiativeJiraConnector"]
    cloud_id: Optional[str] = Field(alias="cloudId")


class QueryFeedsFeedsResultsInitiativeJiraConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsInitiativeGithub(BaseModel):
    authentication_type: Optional[GitHubAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[str]
    repository_owner: Optional[str] = Field(alias="repositoryOwner")
    repository_name: Optional[str] = Field(alias="repositoryName")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsInitiativeGithubConnector"]
    authorization_id: Optional[str] = Field(alias="authorizationId")


class QueryFeedsFeedsResultsInitiativeGithubConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsInitiativeLinear(BaseModel):
    authentication_type: Optional[LinearAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    key: Optional[str]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsInitiativeLinearConnector"]


class QueryFeedsFeedsResultsInitiativeLinearConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsCommit(BaseModel):
    type: FeedServiceTypes
    github: Optional["QueryFeedsFeedsResultsCommitGithub"]
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    read_limit: Optional[int] = Field(alias="readLimit")


class QueryFeedsFeedsResultsCommitGithub(BaseModel):
    authentication_type: Optional[GitHubCommitAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    connector: Optional["QueryFeedsFeedsResultsCommitGithubConnector"]


class QueryFeedsFeedsResultsCommitGithubConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsPullRequest(BaseModel):
    type: FeedServiceTypes
    github: Optional["QueryFeedsFeedsResultsPullRequestGithub"]
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    read_limit: Optional[int] = Field(alias="readLimit")


class QueryFeedsFeedsResultsPullRequestGithub(BaseModel):
    authentication_type: Optional[GitHubPullRequestAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    connector: Optional["QueryFeedsFeedsResultsPullRequestGithubConnector"]


class QueryFeedsFeedsResultsPullRequestGithubConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsCrm(BaseModel):
    type: FeedServiceTypes
    attio: Optional["QueryFeedsFeedsResultsCrmAttio"]
    google_contacts: Optional["QueryFeedsFeedsResultsCrmGoogleContacts"] = Field(
        alias="googleContacts"
    )
    microsoft_contacts: Optional["QueryFeedsFeedsResultsCrmMicrosoftContacts"] = Field(
        alias="microsoftContacts"
    )
    salesforce: Optional["QueryFeedsFeedsResultsCrmSalesforce"]
    hub_spot: Optional["QueryFeedsFeedsResultsCrmHubSpot"] = Field(alias="hubSpot")
    productlane: Optional["QueryFeedsFeedsResultsCrmProductlane"]
    read_limit: Optional[int] = Field(alias="readLimit")


class QueryFeedsFeedsResultsCrmAttio(BaseModel):
    authentication_type: Optional[AttioAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    api_key: Optional[str] = Field(alias="apiKey")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsCrmAttioConnector"]
    type: Optional[FeedListingTypes]


class QueryFeedsFeedsResultsCrmAttioConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsCrmGoogleContacts(BaseModel):
    authentication_type: Optional[GoogleContactsAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsCrmGoogleContactsConnector"]
    type: Optional[FeedListingTypes]


class QueryFeedsFeedsResultsCrmGoogleContactsConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsCrmMicrosoftContacts(BaseModel):
    authentication_type: Optional[MicrosoftContactsAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    tenant_id: Optional[str] = Field(alias="tenantId")
    connector: Optional["QueryFeedsFeedsResultsCrmMicrosoftContactsConnector"]
    type: Optional[FeedListingTypes]


class QueryFeedsFeedsResultsCrmMicrosoftContactsConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsCrmSalesforce(BaseModel):
    authentication_type: Optional[SalesforceAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    instance_url: Optional[str] = Field(alias="instanceUrl")
    is_sandbox: Optional[bool] = Field(alias="isSandbox")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsCrmSalesforceConnector"]
    type: Optional[FeedListingTypes]


class QueryFeedsFeedsResultsCrmSalesforceConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsCrmHubSpot(BaseModel):
    authentication_type: Optional[HubSpotAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    access_token: Optional[str] = Field(alias="accessToken")
    connector: Optional["QueryFeedsFeedsResultsCrmHubSpotConnector"]
    type: Optional[FeedListingTypes]


class QueryFeedsFeedsResultsCrmHubSpotConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsCrmProductlane(BaseModel):
    api_key: Optional[str] = Field(alias="apiKey")
    type: Optional[FeedListingTypes]


class QueryFeedsFeedsResultsHris(BaseModel):
    type: FeedServiceTypes
    bamboo_hr: Optional["QueryFeedsFeedsResultsHrisBambooHr"] = Field(alias="bambooHR")
    gusto: Optional["QueryFeedsFeedsResultsHrisGusto"]
    read_limit: Optional[int] = Field(alias="readLimit")


class QueryFeedsFeedsResultsHrisBambooHr(BaseModel):
    authentication_type: Optional[BambooHRAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    api_key: Optional[str] = Field(alias="apiKey")
    company_domain: Optional[str] = Field(alias="companyDomain")


class QueryFeedsFeedsResultsHrisGusto(BaseModel):
    authentication_type: Optional[GustoAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    company_id: Optional[str] = Field(alias="companyId")


class QueryFeedsFeedsResultsCalendar(BaseModel):
    type: FeedServiceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    enable_meeting_recording: Optional[bool] = Field(alias="enableMeetingRecording")
    meeting_bot_name: Optional[str] = Field(alias="meetingBotName")
    google: Optional["QueryFeedsFeedsResultsCalendarGoogle"]
    microsoft: Optional["QueryFeedsFeedsResultsCalendarMicrosoft"]
    read_limit: Optional[int] = Field(alias="readLimit")


class QueryFeedsFeedsResultsCalendarGoogle(BaseModel):
    type: Optional[CalendarListingTypes]
    calendar_id: Optional[str] = Field(alias="calendarId")
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    authentication_type: Optional[GoogleCalendarAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    connector: Optional["QueryFeedsFeedsResultsCalendarGoogleConnector"]


class QueryFeedsFeedsResultsCalendarGoogleConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsCalendarMicrosoft(BaseModel):
    type: Optional[CalendarListingTypes]
    calendar_id: Optional[str] = Field(alias="calendarId")
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    authentication_type: Optional[MicrosoftCalendarAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    connector: Optional["QueryFeedsFeedsResultsCalendarMicrosoftConnector"]


class QueryFeedsFeedsResultsCalendarMicrosoftConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsMeeting(BaseModel):
    type: FeedServiceTypes
    content_type: Optional[MeetingContentTypes] = Field(alias="contentType")
    read_limit: Optional[int] = Field(alias="readLimit")
    fireflies: Optional["QueryFeedsFeedsResultsMeetingFireflies"]
    attio: Optional["QueryFeedsFeedsResultsMeetingAttio"]
    fathom: Optional["QueryFeedsFeedsResultsMeetingFathom"]
    hub_spot: Optional["QueryFeedsFeedsResultsMeetingHubSpot"] = Field(alias="hubSpot")
    krisp: Optional["QueryFeedsFeedsResultsMeetingKrisp"]


class QueryFeedsFeedsResultsMeetingFireflies(BaseModel):
    api_key: Optional[str] = Field(alias="apiKey")
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    type: Optional[FeedListingTypes]


class QueryFeedsFeedsResultsMeetingAttio(BaseModel):
    authentication_type: Optional[AttioMeetingAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    api_key: Optional[str] = Field(alias="apiKey")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsMeetingAttioConnector"]
    after_date: Optional[Any] = Field(alias="afterDate")
    before_date: Optional[Any] = Field(alias="beforeDate")
    type: Optional[FeedListingTypes]


class QueryFeedsFeedsResultsMeetingAttioConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsMeetingFathom(BaseModel):
    api_key: Optional[str] = Field(alias="apiKey")
    after_date: Optional[Any] = Field(alias="afterDate")
    before_date: Optional[Any] = Field(alias="beforeDate")
    type: Optional[FeedListingTypes]


class QueryFeedsFeedsResultsMeetingHubSpot(BaseModel):
    authentication_type: Optional[HubSpotFeedAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    access_token: Optional[str] = Field(alias="accessToken")
    include_transcripts: Optional[bool] = Field(alias="includeTranscripts")
    after_date: Optional[Any] = Field(alias="afterDate")
    before_date: Optional[Any] = Field(alias="beforeDate")
    read_limit: Optional[int] = Field(alias="readLimit")
    connector: Optional["QueryFeedsFeedsResultsMeetingHubSpotConnector"]
    type: Optional[FeedListingTypes]


class QueryFeedsFeedsResultsMeetingHubSpotConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsMeetingKrisp(BaseModel):
    auth_token: Optional[str] = Field(alias="authToken")
    type: Optional[FeedListingTypes]


class QueryFeedsFeedsResultsRss(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    uri: Any


class QueryFeedsFeedsResultsWeb(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    uri: Any
    include_files: Optional[bool] = Field(alias="includeFiles")
    allowed_paths: Optional[list[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[list[str]] = Field(alias="excludedPaths")


class QueryFeedsFeedsResultsSearch(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[SearchServiceTypes]
    text: Optional[str]
    exa: Optional["QueryFeedsFeedsResultsSearchExa"]
    crustdata: Optional["QueryFeedsFeedsResultsSearchCrustdata"]


class QueryFeedsFeedsResultsSearchExa(BaseModel):
    search_type: Optional[ExaSearchTypes] = Field(alias="searchType")


class QueryFeedsFeedsResultsSearchCrustdata(BaseModel):
    signal_type: Optional[CrustdataWatcherSignalTypes] = Field(alias="signalType")
    company_domain: Optional[str] = Field(alias="companyDomain")
    company_linked_in_url: Optional[str] = Field(alias="companyLinkedInUrl")
    company_id: Optional[str] = Field(alias="companyId")
    person_linked_in_urls: Optional[list[str]] = Field(alias="personLinkedInUrls")
    job_title: Optional[str] = Field(alias="jobTitle")
    job_region: Optional[str] = Field(alias="jobRegion")
    job_description: Optional[str] = Field(alias="jobDescription")


class QueryFeedsFeedsResultsReddit(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    subreddit_name: str = Field(alias="subredditName")


class QueryFeedsFeedsResultsLinkedIn(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    listing_type: Optional[LinkedInPostListingTypes] = Field(alias="listingType")
    company_domain: Optional[str] = Field(alias="companyDomain")
    company_linked_in_url: Optional[str] = Field(alias="companyLinkedInUrl")
    company_name: Optional[str] = Field(alias="companyName")
    person_linked_in_url: Optional[str] = Field(alias="personLinkedInUrl")
    post_types: Optional[str] = Field(alias="postTypes")
    keyword: Optional[str]
    date_posted: Optional[str] = Field(alias="datePosted")
    exact_keyword_match: Optional[bool] = Field(alias="exactKeywordMatch")
    content_types: Optional[list[Optional[LinkedInPostContentTypes]]] = Field(
        alias="contentTypes"
    )
    include_comments: Optional[bool] = Field(alias="includeComments")
    max_comments: Optional[int] = Field(alias="maxComments")


class QueryFeedsFeedsResultsNotion(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[NotionAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    token: Optional[str]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsNotionConnector"]
    identifiers: list[str]
    type: NotionTypes


class QueryFeedsFeedsResultsNotionConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsConfluence(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[ConfluenceAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[str]
    email: Optional[str]
    token: Optional[str]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsConfluenceConnector"]
    cloud_id: Optional[str] = Field(alias="cloudId")
    space_keys: Optional[list[str]] = Field(alias="spaceKeys")
    identifiers: Optional[list[str]]
    type: ConfluenceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class QueryFeedsFeedsResultsConfluenceConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsIntercom(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[IntercomAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    access_token: Optional[str] = Field(alias="accessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsIntercomConnector"]


class QueryFeedsFeedsResultsIntercomConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsZendesk(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[ZendeskAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    subdomain: str
    access_token: Optional[str] = Field(alias="accessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsZendeskConnector"]


class QueryFeedsFeedsResultsZendeskConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsYoutube(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: YouTubeTypes
    video_name: Optional[str] = Field(alias="videoName")
    video_identifiers: Optional[list[str]] = Field(alias="videoIdentifiers")
    channel_identifier: Optional[str] = Field(alias="channelIdentifier")
    playlist_identifier: Optional[str] = Field(alias="playlistIdentifier")


class QueryFeedsFeedsResultsTwitter(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[TwitterAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    token: Optional[str]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsTwitterConnector"]
    type: Optional[TwitterListingTypes]
    user_name: Optional[str] = Field(alias="userName")
    query: Optional[str]
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class QueryFeedsFeedsResultsTwitterConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsSlack(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedListingTypes]
    authentication_type: Optional[SlackAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    token: Optional[str]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsSlackConnector"]
    channel: str
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class QueryFeedsFeedsResultsSlackConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsMicrosoftTeams(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedListingTypes]
    authentication_type: Optional[MicrosoftTeamsAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsMicrosoftTeamsConnector"]
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    team_id: str = Field(alias="teamId")
    channel_id: str = Field(alias="channelId")
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class QueryFeedsFeedsResultsMicrosoftTeamsConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsDiscord(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedListingTypes]
    token: str
    channel: str
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class QueryFeedsFeedsResultsAttio(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[AttioFeedAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    api_key: Optional[str] = Field(alias="apiKey")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsAttioConnector"]


class QueryFeedsFeedsResultsAttioConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsSalesforce(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[SalesforceFeedAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    is_sandbox: Optional[bool] = Field(alias="isSandbox")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsSalesforceConnector"]


class QueryFeedsFeedsResultsSalesforceConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsHubSpotConversations(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[HubSpotFeedAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    access_token: Optional[str] = Field(alias="accessToken")
    inbox_id: Optional[str] = Field(alias="inboxId")
    include_closed_threads: Optional[bool] = Field(alias="includeClosedThreads")
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    connector: Optional["QueryFeedsFeedsResultsHubSpotConversationsConnector"]


class QueryFeedsFeedsResultsHubSpotConversationsConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsIntercomConversations(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[IntercomConversationsAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    access_token: Optional[str] = Field(alias="accessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["QueryFeedsFeedsResultsIntercomConversationsConnector"]
    state: Optional[str]
    include_notes: Optional[bool] = Field(alias="includeNotes")
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class QueryFeedsFeedsResultsIntercomConversationsConnector(BaseModel):
    id: str


class QueryFeedsFeedsResultsProductlane(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: FeedServiceTypes
    api_key: Optional[str] = Field(alias="apiKey")
    workspace_id: Optional[str] = Field(alias="workspaceId")


class QueryFeedsFeedsResultsResearch(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedServiceTypes]
    query: str
    parallel: Optional["QueryFeedsFeedsResultsResearchParallel"]


class QueryFeedsFeedsResultsResearchParallel(BaseModel):
    processor: Optional[ParallelProcessors]


class QueryFeedsFeedsResultsEntity(BaseModel):
    type: FeedServiceTypes
    query: Optional[str]
    read_limit: Optional[int] = Field(alias="readLimit")
    parallel: Optional["QueryFeedsFeedsResultsEntityParallel"]
    crustdata: Optional["QueryFeedsFeedsResultsEntityCrustdata"]


class QueryFeedsFeedsResultsEntityParallel(BaseModel):
    generator: Optional[ParallelGenerators]
    processor: Optional[ParallelProcessors]


class QueryFeedsFeedsResultsEntityCrustdata(BaseModel):
    person_filters: Optional["QueryFeedsFeedsResultsEntityCrustdataPersonFilters"] = (
        Field(alias="personFilters")
    )
    company_filters: Optional["QueryFeedsFeedsResultsEntityCrustdataCompanyFilters"] = (
        Field(alias="companyFilters")
    )


class QueryFeedsFeedsResultsEntityCrustdataPersonFilters(BaseModel):
    titles: Optional[list[str]]
    seniority_levels: Optional[list[str]] = Field(alias="seniorityLevels")
    function_categories: Optional[list[str]] = Field(alias="functionCategories")
    company_names: Optional[list[str]] = Field(alias="companyNames")
    company_domains: Optional[list[str]] = Field(alias="companyDomains")
    company_linked_in_urls: Optional[list[str]] = Field(alias="companyLinkedInUrls")
    industries: Optional[list[str]]
    regions: Optional[list[str]]
    countries: Optional[list[str]]
    skills: Optional[list[str]]
    schools: Optional[list[str]]
    min_years_experience: Optional[int] = Field(alias="minYearsExperience")
    max_years_experience: Optional[int] = Field(alias="maxYearsExperience")
    min_connections: Optional[int] = Field(alias="minConnections")
    recently_changed_jobs: Optional[bool] = Field(alias="recentlyChangedJobs")


class QueryFeedsFeedsResultsEntityCrustdataCompanyFilters(BaseModel):
    names: Optional[list[str]]
    domains: Optional[list[str]]
    industries: Optional[list[str]]
    categories: Optional[list[str]]
    countries: Optional[list[str]]
    locations: Optional[list[str]]
    company_types: Optional[list[str]] = Field(alias="companyTypes")
    min_employee_count: Optional[int] = Field(alias="minEmployeeCount")
    max_employee_count: Optional[int] = Field(alias="maxEmployeeCount")
    min_growth_6_m_percent: Optional[Any] = Field(alias="minGrowth6mPercent")
    min_growth_12_m_percent: Optional[Any] = Field(alias="minGrowth12mPercent")
    funding_round_types: Optional[list[str]] = Field(alias="fundingRoundTypes")
    min_funding_date: Optional[Any] = Field(alias="minFundingDate")
    min_total_funding_usd: Optional[Any] = Field(alias="minTotalFundingUsd")
    min_revenue_lower_bound_usd: Optional[Any] = Field(alias="minRevenueLowerBoundUsd")
    max_revenue_upper_bound_usd: Optional[Any] = Field(alias="maxRevenueUpperBoundUsd")
    min_year_founded: Optional[int] = Field(alias="minYearFounded")
    max_year_founded: Optional[int] = Field(alias="maxYearFounded")


class QueryFeedsFeedsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryFeedsFeedsResultsSchedulePolicy(BaseModel):
    recurrence_type: Optional[TimedPolicyRecurrenceTypes] = Field(
        alias="recurrenceType"
    )
    repeat_interval: Optional[Any] = Field(alias="repeatInterval")


QueryFeeds.model_rebuild()
QueryFeedsFeeds.model_rebuild()
QueryFeedsFeedsResults.model_rebuild()
QueryFeedsFeedsResultsSite.model_rebuild()
QueryFeedsFeedsResultsSiteSharePoint.model_rebuild()
QueryFeedsFeedsResultsSiteOneDrive.model_rebuild()
QueryFeedsFeedsResultsSiteGoogleDrive.model_rebuild()
QueryFeedsFeedsResultsSiteDropbox.model_rebuild()
QueryFeedsFeedsResultsSiteBox.model_rebuild()
QueryFeedsFeedsResultsSiteGithub.model_rebuild()
QueryFeedsFeedsResultsEmail.model_rebuild()
QueryFeedsFeedsResultsEmailGoogle.model_rebuild()
QueryFeedsFeedsResultsEmailMicrosoft.model_rebuild()
QueryFeedsFeedsResultsIssue.model_rebuild()
QueryFeedsFeedsResultsIssueJira.model_rebuild()
QueryFeedsFeedsResultsIssueLinear.model_rebuild()
QueryFeedsFeedsResultsIssueGithub.model_rebuild()
QueryFeedsFeedsResultsIssueIntercom.model_rebuild()
QueryFeedsFeedsResultsIssueZendesk.model_rebuild()
QueryFeedsFeedsResultsIssueAttio.model_rebuild()
QueryFeedsFeedsResultsIssueSalesforce.model_rebuild()
QueryFeedsFeedsResultsIssueHubSpot.model_rebuild()
QueryFeedsFeedsResultsInitiative.model_rebuild()
QueryFeedsFeedsResultsInitiativeJira.model_rebuild()
QueryFeedsFeedsResultsInitiativeGithub.model_rebuild()
QueryFeedsFeedsResultsInitiativeLinear.model_rebuild()
QueryFeedsFeedsResultsCommit.model_rebuild()
QueryFeedsFeedsResultsCommitGithub.model_rebuild()
QueryFeedsFeedsResultsPullRequest.model_rebuild()
QueryFeedsFeedsResultsPullRequestGithub.model_rebuild()
QueryFeedsFeedsResultsCrm.model_rebuild()
QueryFeedsFeedsResultsCrmAttio.model_rebuild()
QueryFeedsFeedsResultsCrmGoogleContacts.model_rebuild()
QueryFeedsFeedsResultsCrmMicrosoftContacts.model_rebuild()
QueryFeedsFeedsResultsCrmSalesforce.model_rebuild()
QueryFeedsFeedsResultsCrmHubSpot.model_rebuild()
QueryFeedsFeedsResultsHris.model_rebuild()
QueryFeedsFeedsResultsCalendar.model_rebuild()
QueryFeedsFeedsResultsCalendarGoogle.model_rebuild()
QueryFeedsFeedsResultsCalendarMicrosoft.model_rebuild()
QueryFeedsFeedsResultsMeeting.model_rebuild()
QueryFeedsFeedsResultsMeetingAttio.model_rebuild()
QueryFeedsFeedsResultsMeetingHubSpot.model_rebuild()
QueryFeedsFeedsResultsSearch.model_rebuild()
QueryFeedsFeedsResultsNotion.model_rebuild()
QueryFeedsFeedsResultsConfluence.model_rebuild()
QueryFeedsFeedsResultsIntercom.model_rebuild()
QueryFeedsFeedsResultsZendesk.model_rebuild()
QueryFeedsFeedsResultsTwitter.model_rebuild()
QueryFeedsFeedsResultsSlack.model_rebuild()
QueryFeedsFeedsResultsMicrosoftTeams.model_rebuild()
QueryFeedsFeedsResultsAttio.model_rebuild()
QueryFeedsFeedsResultsSalesforce.model_rebuild()
QueryFeedsFeedsResultsHubSpotConversations.model_rebuild()
QueryFeedsFeedsResultsIntercomConversations.model_rebuild()
QueryFeedsFeedsResultsResearch.model_rebuild()
QueryFeedsFeedsResultsEntity.model_rebuild()
QueryFeedsFeedsResultsEntityCrustdata.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllMedicalDrugClasses(BaseModel):
    delete_all_medical_drug_classes: Optional[
        list[Optional["DeleteAllMedicalDrugClassesDeleteAllMedicalDrugClasses"]]
    ] = Field(alias="deleteAllMedicalDrugClasses")


class DeleteAllMedicalDrugClassesDeleteAllMedicalDrugClasses(BaseModel):
    id: str
    state: EntityState


DeleteAllMedicalDrugClasses.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import AgentTypes, EntityState


class UpsertAgent(BaseModel):
    upsert_agent: Optional["UpsertAgentUpsertAgent"] = Field(alias="upsertAgent")


class UpsertAgentUpsertAgent(BaseModel):
    id: str
    name: str
    state: EntityState
    type: AgentTypes


UpsertAgent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteCollections(BaseModel):
    delete_collections: Optional[
        list[Optional["DeleteCollectionsDeleteCollections"]]
    ] = Field(alias="deleteCollections")


class DeleteCollectionsDeleteCollections(BaseModel):
    id: str
    state: EntityState


DeleteCollections.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAgents(BaseModel):
    delete_agents: Optional[list[Optional["DeleteAgentsDeleteAgents"]]] = Field(
        alias="deleteAgents"
    )


class DeleteAgentsDeleteAgents(BaseModel):
    id: str
    state: EntityState


DeleteAgents.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalDrugs(BaseModel):
    count_medical_drugs: Optional["CountMedicalDrugsCountMedicalDrugs"] = Field(
        alias="countMedicalDrugs"
    )


class CountMedicalDrugsCountMedicalDrugs(BaseModel):
    count: Optional[Any]


CountMedicalDrugs.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, FactCategory, ObservableTypes, SourceTypes


class QueryFacts(BaseModel):
    facts: Optional["QueryFactsFacts"]


class QueryFactsFacts(BaseModel):
    results: Optional[list[Optional["QueryFactsFactsResults"]]]


class QueryFactsFactsResults(BaseModel):
    id: str
    creation_date: Any = Field(alias="creationDate")
    owner: "QueryFactsFactsResultsOwner"
    state: EntityState
    text: str
    valid_at: Optional[Any] = Field(alias="validAt")
    invalid_at: Optional[Any] = Field(alias="invalidAt")
    relevance: Optional[float]
    mentions: Optional[list[Optional["QueryFactsFactsResultsMentions"]]]
    assertions: Optional[list[Optional["QueryFactsFactsResultsAssertions"]]]
    feeds: Optional[list[Optional["QueryFactsFactsResultsFeeds"]]]
    content: Optional["QueryFactsFactsResultsContent"]
    conversation: Optional["QueryFactsFactsResultsConversation"]
    persona: Optional["QueryFactsFactsResultsPersona"]
    source_type: Optional[SourceTypes] = Field(alias="sourceType")
    category: Optional[FactCategory]
    confidence: Optional[float]


class QueryFactsFactsResultsOwner(BaseModel):
    id: str


class QueryFactsFactsResultsMentions(BaseModel):
    type: Optional[ObservableTypes]
    observable: Optional["QueryFactsFactsResultsMentionsObservable"]
    start: Optional[int]
    end: Optional[int]


class QueryFactsFactsResultsMentionsObservable(BaseModel):
    id: str
    name: Optional[str]


class QueryFactsFactsResultsAssertions(BaseModel):
    text: str
    mentions: Optional[list[Optional["QueryFactsFactsResultsAssertionsMentions"]]]


class QueryFactsFactsResultsAssertionsMentions(BaseModel):
    type: Optional[ObservableTypes]
    observable: Optional["QueryFactsFactsResultsAssertionsMentionsObservable"]
    start: Optional[int]
    end: Optional[int]


class QueryFactsFactsResultsAssertionsMentionsObservable(BaseModel):
    id: str
    name: Optional[str]


class QueryFactsFactsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryFactsFactsResultsContent(BaseModel):
    id: str
    name: str


class QueryFactsFactsResultsConversation(BaseModel):
    id: str
    name: str


class QueryFactsFactsResultsPersona(BaseModel):
    id: str
    name: str


QueryFacts.model_rebuild()
QueryFactsFacts.model_rebuild()
QueryFactsFactsResults.model_rebuild()
QueryFactsFactsResultsMentions.model_rebuild()
QueryFactsFactsResultsAssertions.model_rebuild()
QueryFactsFactsResultsAssertionsMentions.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import AlertTypes, EntityState


class CreateAlert(BaseModel):
    create_alert: Optional["CreateAlertCreateAlert"] = Field(alias="createAlert")


class CreateAlertCreateAlert(BaseModel):
    id: str
    name: str
    state: EntityState
    type: AlertTypes


CreateAlert.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryBambooHRDepartments(BaseModel):
    bamboo_hr_departments: Optional["QueryBambooHRDepartmentsBambooHrDepartments"] = (
        Field(alias="bambooHRDepartments")
    )


class QueryBambooHRDepartmentsBambooHrDepartments(BaseModel):
    results: Optional[
        list[Optional["QueryBambooHRDepartmentsBambooHrDepartmentsResults"]]
    ]


class QueryBambooHRDepartmentsBambooHrDepartmentsResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryBambooHRDepartments.model_rebuild()
QueryBambooHRDepartmentsBambooHrDepartments.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import AgentTypes, EntityState


class UpdateAgent(BaseModel):
    update_agent: Optional["UpdateAgentUpdateAgent"] = Field(alias="updateAgent")


class UpdateAgentUpdateAgent(BaseModel):
    id: str
    name: str
    state: EntityState
    type: AgentTypes


UpdateAgent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllPlaces(BaseModel):
    delete_all_places: Optional[list[Optional["DeleteAllPlacesDeleteAllPlaces"]]] = (
        Field(alias="deleteAllPlaces")
    )


class DeleteAllPlacesDeleteAllPlaces(BaseModel):
    id: str
    state: EntityState


DeleteAllPlaces.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllInvestments(BaseModel):
    delete_all_investments: Optional[
        list[Optional["DeleteAllInvestmentsDeleteAllInvestments"]]
    ] = Field(alias="deleteAllInvestments")


class DeleteAllInvestmentsDeleteAllInvestments(BaseModel):
    id: str
    state: EntityState


DeleteAllInvestments.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityTypes


class QueryContentsGraph(BaseModel):
    contents: Optional["QueryContentsGraphContents"]


class QueryContentsGraphContents(BaseModel):
    graph: Optional["QueryContentsGraphContentsGraph"]


class QueryContentsGraphContentsGraph(BaseModel):
    nodes: Optional[list[Optional["QueryContentsGraphContentsGraphNodes"]]]
    edges: Optional[list[Optional["QueryContentsGraphContentsGraphEdges"]]]


class QueryContentsGraphContentsGraphNodes(BaseModel):
    id: str
    name: str
    type: EntityTypes
    metadata: Optional[str]


class QueryContentsGraphContentsGraphEdges(BaseModel):
    from_: str = Field(alias="from")
    to: str
    relation: Optional[str]


QueryContentsGraph.model_rebuild()
QueryContentsGraphContents.model_rebuild()
QueryContentsGraphContentsGraph.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGustoCompanies(BaseModel):
    gusto_companies: Optional["QueryGustoCompaniesGustoCompanies"] = Field(
        alias="gustoCompanies"
    )


class QueryGustoCompaniesGustoCompanies(BaseModel):
    results: Optional[list[Optional["QueryGustoCompaniesGustoCompaniesResults"]]]


class QueryGustoCompaniesGustoCompaniesResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]
    ein: Optional[str]


QueryGustoCompanies.model_rebuild()
QueryGustoCompaniesGustoCompanies.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class CreateFact(BaseModel):
    create_fact: Optional["CreateFactCreateFact"] = Field(alias="createFact")


class CreateFactCreateFact(BaseModel):
    id: str
    state: EntityState


CreateFact.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountFacts(BaseModel):
    count_facts: Optional["CountFactsCountFacts"] = Field(alias="countFacts")


class CountFactsCountFacts(BaseModel):
    count: Optional[Any]


CountFacts.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryMicrosoftTeamsTeams(BaseModel):
    microsoft_teams_teams: Optional["QueryMicrosoftTeamsTeamsMicrosoftTeamsTeams"] = (
        Field(alias="microsoftTeamsTeams")
    )


class QueryMicrosoftTeamsTeamsMicrosoftTeamsTeams(BaseModel):
    results: Optional[
        list[Optional["QueryMicrosoftTeamsTeamsMicrosoftTeamsTeamsResults"]]
    ]


class QueryMicrosoftTeamsTeamsMicrosoftTeamsTeamsResults(BaseModel):
    team_name: Optional[str] = Field(alias="teamName")
    team_id: Optional[str] = Field(alias="teamId")


QueryMicrosoftTeamsTeams.model_rebuild()
QueryMicrosoftTeamsTeamsMicrosoftTeamsTeams.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import SummarizationTypes


class SummarizeText(BaseModel):
    summarize_text: Optional["SummarizeTextSummarizeText"] = Field(
        alias="summarizeText"
    )


class SummarizeTextSummarizeText(BaseModel):
    specification: Optional["SummarizeTextSummarizeTextSpecification"]
    content: Optional["SummarizeTextSummarizeTextContent"]
    type: SummarizationTypes
    items: Optional[list["SummarizeTextSummarizeTextItems"]]
    error: Optional[str]


class SummarizeTextSummarizeTextSpecification(BaseModel):
    id: str


class SummarizeTextSummarizeTextContent(BaseModel):
    id: str


class SummarizeTextSummarizeTextItems(BaseModel):
    text: Optional[str]
    tokens: int
    summarization_time: Optional[Any] = Field(alias="summarizationTime")


SummarizeText.model_rebuild()
SummarizeTextSummarizeText.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class UpdateFact(BaseModel):
    update_fact: Optional["UpdateFactUpdateFact"] = Field(alias="updateFact")


class UpdateFactUpdateFact(BaseModel):
    id: str
    state: EntityState


UpdateFact.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryOneDriveFolders(BaseModel):
    one_drive_folders: Optional["QueryOneDriveFoldersOneDriveFolders"] = Field(
        alias="oneDriveFolders"
    )


class QueryOneDriveFoldersOneDriveFolders(BaseModel):
    results: Optional[list[Optional["QueryOneDriveFoldersOneDriveFoldersResults"]]]


class QueryOneDriveFoldersOneDriveFoldersResults(BaseModel):
    folder_name: Optional[str] = Field(alias="folderName")
    folder_id: Optional[str] = Field(alias="folderId")
    folder_path: Optional[str] = Field(alias="folderPath")


QueryOneDriveFolders.model_rebuild()
QueryOneDriveFoldersOneDriveFolders.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllSkills(BaseModel):
    delete_all_skills: Optional[list[Optional["DeleteAllSkillsDeleteAllSkills"]]] = (
        Field(alias="deleteAllSkills")
    )


class DeleteAllSkillsDeleteAllSkills(BaseModel):
    id: str
    state: EntityState


DeleteAllSkills.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DisableAlert(BaseModel):
    disable_alert: Optional["DisableAlertDisableAlert"] = Field(alias="disableAlert")


class DisableAlertDisableAlert(BaseModel):
    id: str
    state: EntityState


DisableAlert.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class EnableAgent(BaseModel):
    enable_agent: Optional["EnableAgentEnableAgent"] = Field(alias="enableAgent")


class EnableAgentEnableAgent(BaseModel):
    id: str
    state: EntityState


EnableAgent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryAsanaWorkspaces(BaseModel):
    asana_workspaces: Optional["QueryAsanaWorkspacesAsanaWorkspaces"] = Field(
        alias="asanaWorkspaces"
    )


class QueryAsanaWorkspacesAsanaWorkspaces(BaseModel):
    results: Optional[list[str]]


QueryAsanaWorkspaces.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteSpecifications(BaseModel):
    delete_specifications: Optional[
        list[Optional["DeleteSpecificationsDeleteSpecifications"]]
    ] = Field(alias="deleteSpecifications")


class DeleteSpecificationsDeleteSpecifications(BaseModel):
    id: str
    state: EntityState


DeleteSpecifications.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ContentTypes, FileTypes, ObservableTypes


class PreviewFeed(BaseModel):
    preview_feed: Optional["PreviewFeedPreviewFeed"] = Field(alias="previewFeed")


class PreviewFeedPreviewFeed(BaseModel):
    is_complete: bool = Field(alias="isComplete")
    item_count: Any = Field(alias="itemCount")
    estimated_bytes: Optional[Any] = Field(alias="estimatedBytes")
    content_type_summary: Optional[list["PreviewFeedPreviewFeedContentTypeSummary"]] = (
        Field(alias="contentTypeSummary")
    )
    observable_type_summary: Optional[
        list["PreviewFeedPreviewFeedObservableTypeSummary"]
    ] = Field(alias="observableTypeSummary")
    warnings: Optional[list[str]]


class PreviewFeedPreviewFeedContentTypeSummary(BaseModel):
    content_type: ContentTypes = Field(alias="contentType")
    file_type: Optional[FileTypes] = Field(alias="fileType")
    item_count: Any = Field(alias="itemCount")
    total_bytes: Optional[Any] = Field(alias="totalBytes")


class PreviewFeedPreviewFeedObservableTypeSummary(BaseModel):
    observable_type: ObservableTypes = Field(alias="observableType")
    item_count: Any = Field(alias="itemCount")


PreviewFeed.model_rebuild()
PreviewFeedPreviewFeed.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAgent(BaseModel):
    delete_agent: Optional["DeleteAgentDeleteAgent"] = Field(alias="deleteAgent")


class DeleteAgentDeleteAgent(BaseModel):
    id: str
    state: EntityState


DeleteAgent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountPersons(BaseModel):
    count_persons: Optional["CountPersonsCountPersons"] = Field(alias="countPersons")


class CountPersonsCountPersons(BaseModel):
    count: Optional[Any]


CountPersons.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class AddSkillsToCollections(BaseModel):
    add_skills_to_collections: Optional[
        list[Optional["AddSkillsToCollectionsAddSkillsToCollections"]]
    ] = Field(alias="addSkillsToCollections")


class AddSkillsToCollectionsAddSkillsToCollections(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[
        list[Optional["AddSkillsToCollectionsAddSkillsToCollectionsContents"]]
    ]


class AddSkillsToCollectionsAddSkillsToCollectionsContents(BaseModel):
    id: str
    name: str


AddSkillsToCollections.model_rebuild()
AddSkillsToCollectionsAddSkillsToCollections.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    AgentChannelTypes,
    AgentTypes,
    ContentTypes,
    EntityState,
    FileTypes,
    TimedPolicyRecurrenceTypes,
)


class GetAgent(BaseModel):
    agent: Optional["GetAgentAgent"]


class GetAgentAgent(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetAgentAgentOwner"
    state: EntityState
    correlation_id: Optional[str] = Field(alias="correlationId")
    type: AgentTypes
    specification: Optional["GetAgentAgentSpecification"]
    filter: Optional["GetAgentAgentFilter"]
    schedule_policy: Optional["GetAgentAgentSchedulePolicy"] = Field(
        alias="schedulePolicy"
    )
    channels: Optional[list["GetAgentAgentChannels"]]
    connectors: Optional[list["GetAgentAgentConnectors"]]
    timeout: Optional[Any]
    prompt: Optional[str]
    scratchpad: Optional[str]


class GetAgentAgentOwner(BaseModel):
    id: str


class GetAgentAgentSpecification(BaseModel):
    id: str


class GetAgentAgentFilter(BaseModel):
    types: Optional[list[ContentTypes]]
    file_types: Optional[list[FileTypes]] = Field(alias="fileTypes")
    feeds: Optional[list["GetAgentAgentFilterFeeds"]]


class GetAgentAgentFilterFeeds(BaseModel):
    id: str


class GetAgentAgentSchedulePolicy(BaseModel):
    recurrence_type: Optional[TimedPolicyRecurrenceTypes] = Field(
        alias="recurrenceType"
    )
    repeat_interval: Optional[Any] = Field(alias="repeatInterval")
    cron: Optional[str]
    time_zone_id: Optional[str] = Field(alias="timeZoneId")


class GetAgentAgentChannels(BaseModel):
    type: AgentChannelTypes
    identifier: str
    instructions: Optional[str]
    label: Optional[str]


class GetAgentAgentConnectors(BaseModel):
    id: str


GetAgent.model_rebuild()
GetAgentAgent.model_rebuild()
GetAgentAgentFilter.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ArcadeProviders,
    AuthenticationServiceTypes,
    ConnectorTypes,
    EntityState,
    IntegrationServiceTypes,
    MCPServerTypes,
    OAuthProviders,
    UserTypes,
)


class GetUser(BaseModel):
    user: Optional["GetUserUser"]


class GetUserUser(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "GetUserUserOwner"
    state: EntityState
    type: Optional[UserTypes]
    identifier: str
    description: Optional[str]
    connectors: Optional[list[Optional["GetUserUserConnectors"]]]
    personas: Optional[list[Optional["GetUserUserPersonas"]]]
    quota: Optional["GetUserUserQuota"]
    credits: Optional[Any]
    last_credits_date: Optional[Any] = Field(alias="lastCreditsDate")
    accumulated_credits: Optional[Any] = Field(alias="accumulatedCredits")


class GetUserUserOwner(BaseModel):
    id: str


class GetUserUserConnectors(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ConnectorTypes]
    authentication: Optional["GetUserUserConnectorsAuthentication"]
    integration: Optional["GetUserUserConnectorsIntegration"]


class GetUserUserConnectorsAuthentication(BaseModel):
    type: AuthenticationServiceTypes
    token: Optional[str]
    api_key: Optional[str] = Field(alias="apiKey")
    microsoft: Optional["GetUserUserConnectorsAuthenticationMicrosoft"]
    google: Optional["GetUserUserConnectorsAuthenticationGoogle"]
    oauth: Optional["GetUserUserConnectorsAuthenticationOauth"]
    arcade: Optional["GetUserUserConnectorsAuthenticationArcade"]


class GetUserUserConnectorsAuthenticationMicrosoft(BaseModel):
    tenant_id: str = Field(alias="tenantId")
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")


class GetUserUserConnectorsAuthenticationGoogle(BaseModel):
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")


class GetUserUserConnectorsAuthenticationOauth(BaseModel):
    provider: OAuthProviders
    client_id: str = Field(alias="clientId")
    client_secret: str = Field(alias="clientSecret")
    refresh_token: str = Field(alias="refreshToken")
    redirect_uri: Optional[str] = Field(alias="redirectUri")
    metadata: Optional[str]


class GetUserUserConnectorsAuthenticationArcade(BaseModel):
    authorization_id: str = Field(alias="authorizationId")
    provider: ArcadeProviders
    metadata: Optional[str]


class GetUserUserConnectorsIntegration(BaseModel):
    type: IntegrationServiceTypes
    uri: Optional[str]
    slack: Optional["GetUserUserConnectorsIntegrationSlack"]
    email: Optional["GetUserUserConnectorsIntegrationEmail"]
    twitter: Optional["GetUserUserConnectorsIntegrationTwitter"]
    mcp: Optional["GetUserUserConnectorsIntegrationMcp"]


class GetUserUserConnectorsIntegrationSlack(BaseModel):
    token: str
    channel: str


class GetUserUserConnectorsIntegrationEmail(BaseModel):
    from_: str = Field(alias="from")
    subject: str
    to: list[str]


class GetUserUserConnectorsIntegrationTwitter(BaseModel):
    consumer_key: str = Field(alias="consumerKey")
    consumer_secret: str = Field(alias="consumerSecret")
    access_token_key: str = Field(alias="accessTokenKey")
    access_token_secret: str = Field(alias="accessTokenSecret")


class GetUserUserConnectorsIntegrationMcp(BaseModel):
    token: Optional[str]
    type: MCPServerTypes


class GetUserUserPersonas(BaseModel):
    id: str
    name: str
    state: EntityState
    identifier: Optional[str]
    platform: Optional[str]
    display_name: Optional[str] = Field(alias="displayName")
    timezone: Optional[str]
    role: Optional[str]
    instructions: Optional[str]
    facts: Optional[list["GetUserUserPersonasFacts"]]


class GetUserUserPersonasFacts(BaseModel):
    id: Optional[str]
    text: Optional[str]


class GetUserUserQuota(BaseModel):
    credits: Optional[int]


GetUser.model_rebuild()
GetUserUser.model_rebuild()
GetUserUserConnectors.model_rebuild()
GetUserUserConnectorsAuthentication.model_rebuild()
GetUserUserConnectorsIntegration.model_rebuild()
GetUserUserPersonas.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteSkills(BaseModel):
    delete_skills: Optional[list[Optional["DeleteSkillsDeleteSkills"]]] = Field(
        alias="deleteSkills"
    )


class DeleteSkillsDeleteSkills(BaseModel):
    id: str
    state: EntityState


DeleteSkills.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateInvestmentFund(BaseModel):
    create_investment_fund: Optional["CreateInvestmentFundCreateInvestmentFund"] = (
        Field(alias="createInvestmentFund")
    )


class CreateInvestmentFundCreateInvestmentFund(BaseModel):
    id: str
    name: str


CreateInvestmentFund.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllAlerts(BaseModel):
    delete_all_alerts: Optional[list[Optional["DeleteAllAlertsDeleteAllAlerts"]]] = (
        Field(alias="deleteAllAlerts")
    )


class DeleteAllAlertsDeleteAllAlerts(BaseModel):
    id: str
    state: EntityState


DeleteAllAlerts.model_rebuild()
